@@ -21,25 +21,47 @@ from wsme import types as wtypes
 from ironic.api.controllers import base
 from ironic.api.controllers import link
 from ironic.api.controllers import v1
+from ironic.api.controllers.v1 import versions
 from ironic.api import expose
 
+ID_VERSION1 = 'v1'
+
 
 class Version(base.APIBase):
-    """An API version representation."""
+    """An API version representation.
+
+    This class represents an API version, including the minimum and
+    maximum minor versions that are supported within the major version.
+    """
 
     id = wtypes.text
-    """The ID of the version, also acts as the release number"""
+    """The ID of the (major) version, also acts as the release number"""
 
     links = [link.Link]
     """A Link that point to a specific version of the API"""
 
-    @staticmethod
-    def convert(id):
-        version = Version()
-        version.id = id
-        version.links = [link.Link.make_link('self', pecan.request.public_url,
-                                             id, '', bookmark=True)]
-        return version
+    status = wtypes.text
+    """Status of the version.
+
+    One of:
+    * CURRENT - the latest version of API,
+    * SUPPORTED - supported, but not latest, version of API,
+    * DEPRECATED - supported, but deprecated, version of API.
+    """
+
+    version = wtypes.text
+    """The current, maximum supported (major.minor) version of API."""
+
+    min_version = wtypes.text
+    """Minimum supported (major.minor) version of API."""
+
+    def __init__(self, id, min_version, version, status='CURRENT'):
+        self.id = id
+        self.links = [link.Link.make_link('self', pecan.request.public_url,
+                                          self.id, '', bookmark=True)]
+        self.status = status
+        self.version = version
+        self.min_version = min_version
 
 
 class Root(base.APIBase):
@@ -62,17 +84,19 @@ class Root(base.APIBase):
         root.name = "OpenStack Ironic API"
         root.description = ("Ironic is an OpenStack project which aims to "
                             "provision baremetal machines.")
-        root.versions = [Version.convert('v1')]
-        root.default_version = Version.convert('v1')
+        root.default_version = Version(ID_VERSION1,
+                                       versions.MIN_VERSION_STRING,
+                                       versions.MAX_VERSION_STRING)
+        root.versions = [root.default_version]
         return root
 
 
 class RootController(rest.RestController):
 
-    _versions = ['v1']
+    _versions = [ID_VERSION1]
     """All supported API versions"""
 
-    _default_version = 'v1'
+    _default_version = ID_VERSION1
     """The default API version"""
 
     v1 = v1.Controller()
