@@ -45,3 +45,7 @@ def main():
 
     launcher = service.launch(CONF, mgr)
     launcher.wait()
+
+
+if __name__ == '__main__':
+    sys.exit(main())
