@@ -161,6 +161,18 @@ class PortAlreadyExists(Conflict):
     _msg_fmt = _("A port with UUID %(uuid)s already exists.")
 
 
+class PortgroupAlreadyExists(Conflict):
+    _msg_fmt = _("A portgroup with UUID %(uuid)s already exists.")
+
+
+class PortgroupDuplicateName(Conflict):
+    _msg_fmt = _("A portgroup with name %(name)s already exists.")
+
+
+class PortgroupMACAlreadyExists(Conflict):
+    _msg_fmt = _("A portgroup with MAC address %(mac)s already exists.")
+
+
 class InstanceAssociated(Conflict):
     _msg_fmt = _("Instance %(instance_uuid)s is already associated with a "
                  "node, it cannot be associated with this other node %(node)s")
@@ -255,6 +267,15 @@ class NodeNotFound(NotFound):
     _msg_fmt = _("Node %(node)s could not be found.")
 
 
+class PortgroupNotFound(NotFound):
+    _msg_fmt = _("Portgroup %(portgroup)s could not be found.")
+
+
+class PortgroupNotEmpty(Invalid):
+    _msg_fmt = _("Cannot complete the requested action because portgroup "
+                 "%(portgroup)s contains ports.")
+
+
 class NodeAssociated(InvalidState):
     _msg_fmt = _("Node %(node)s is associated with instance %(instance)s.")
 
@@ -484,36 +505,8 @@ class IloOperationNotSupported(IronicException):
     _msg_fmt = _("%(operation)s not supported. error: %(error)s")
 
 
-class DracRequestFailed(IronicException):
-    pass
-
-
-class DracClientError(DracRequestFailed):
-    _msg_fmt = _('DRAC client failed. '
-                 'Last error (cURL error code): %(last_error)s, '
-                 'fault string: "%(fault_string)s" '
-                 'response_code: %(response_code)s')
-
-
-class DracOperationFailed(DracRequestFailed):
-    _msg_fmt = _('DRAC operation failed. _msg_fmt: %(_msg_fmt)s')
-
-
-class DracUnexpectedReturnValue(DracRequestFailed):
-    _msg_fmt = _('DRAC operation yielded return value %(actual_return_value)s '
-                 'that is neither error nor expected '
-                 '%(expected_return_value)s')
-
-
-class DracPendingConfigJobExists(IronicException):
-    _msg_fmt = _('Another job with ID %(job_id)s is already created  '
-                 'to configure %(target)s. Wait until existing job '
-                 'is completed or is canceled')
-
-
-class DracInvalidFilterDialect(IronicException):
-    _msg_fmt = _('Invalid filter dialect \'%(invalid_filter)s\'. '
-                 'Supported options are %(supported)s')
+class DracOperationError(IronicException):
+    _msg_fmt = _('DRAC operation failed. Reason: %(error)s')
 
 
 class FailedToGetSensorData(IronicException):
@@ -608,3 +601,7 @@ class CIMCException(IronicException):
 
 class OneViewError(IronicException):
     _msg_fmt = _("OneView exception occurred. Error: %(error)s")
+
+
+class NodeTagNotFound(IronicException):
+    _msg_fmt = _("Node %(node_id)s doesn't have a tag '%(tag)s'")
