@@ -78,11 +78,13 @@ class ConductorAPI(object):
     |    1.31 - Added Versioned Objects indirection API methods:
     |           object_class_action_versions, object_action and
     |           object_backport_versions
+    |    1.32 - Add do_node_clean
+    |    1.33 - Added update and destroy portgroup.
 
     """
 
     # NOTE(rloo): This must be in sync with manager.ConductorManager's.
-    RPC_API_VERSION = '1.31'
+    RPC_API_VERSION = '1.33'
 
     def __init__(self, topic=None):
         super(ConductorAPI, self).__init__()
@@ -434,6 +436,38 @@ class ConductorAPI(object):
         cctxt = self.client.prepare(topic=topic or self.topic, version='1.13')
         return cctxt.call(context, 'update_port', port_obj=port_obj)
 
+    def update_portgroup(self, context, portgroup_obj, topic=None):
+        """Synchronously, have a conductor update the portgroup's information.
+
+        Update the portgroup's information in the database and return a
+        portgroup object.
+        The conductor will lock related node and trigger specific driver
+        actions if they are needed.
+
+        :param context: request context.
+        :param portgroup_obj: a changed (but not saved) portgroup object.
+        :param topic: RPC topic. Defaults to self.topic.
+        :returns: updated portgroup object, including all fields.
+
+        """
+        cctxt = self.client.prepare(topic=topic or self.topic, version='1.33')
+        return cctxt.call(context, 'update_portgroup',
+                          portgroup_obj=portgroup_obj)
+
+    def destroy_portgroup(self, context, portgroup, topic=None):
+        """Delete a portgroup.
+
+        :param context: request context.
+        :param portgroup: portgroup object
+        :param topic: RPC topic. Defaults to self.topic.
+        :raises: NodeLocked if node is locked by another conductor.
+        :raises: NodeNotFound if the node associated with the portgroup does
+                 not exist.
+        :raises: PortgroupNotEmpty if portgroup is not empty
+        """
+        cctxt = self.client.prepare(topic=topic or self.topic, version='1.33')
+        return cctxt.call(context, 'destroy_portgroup', portgroup=portgroup)
+
     def get_driver_properties(self, context, driver_name, topic=None):
         """Get the properties of the driver.
 
@@ -593,6 +627,25 @@ class ConductorAPI(object):
         return cctxt.call(context, 'get_raid_logical_disk_properties',
                           driver_name=driver_name)
 
+    def do_node_clean(self, context, node_id, clean_steps, topic=None):
+        """Signal to conductor service to perform manual cleaning on a node.
+
+        :param context: request context.
+        :param node_id: node ID or UUID.
+        :param clean_steps: a list of clean step dictionaries.
+        :param topic: RPC topic. Defaults to self.topic.
+        :raises: InvalidParameterValue if validation of power driver interface
+                 failed.
+        :raises: InvalidStateRequested if cleaning can not be performed.
+        :raises: NodeInMaintenance if node is in maintenance mode.
+        :raises: NodeLocked if node is locked by another conductor.
+        :raises: NoFreeConductorWorker when there is no free worker to start
+                 async task.
+        """
+        cctxt = self.client.prepare(topic=topic or self.topic, version='1.32')
+        return cctxt.call(context, 'do_node_clean',
+                          node_id=node_id, clean_steps=clean_steps)
+
     def object_class_action_versions(self, context, objname, objmethod,
                                      object_versions, args, kwargs):
         """Perform an action on a VersionedObject class.
@@ -606,13 +659,15 @@ class ConductorAPI(object):
         :param object_versions: A dict of {objname: version} mappings
         :param args: The positional arguments to the action method
         :param kwargs: The keyword arguments to the action method
-        :raises: NotImplemented when an operator makes an error during upgrade
+        :raises: NotImplementedError when an operator makes an error during
+            upgrade
         :returns: The result of the action method, which may (or may not)
             be an instance of the implementing VersionedObject class.
         """
         if not self.client.can_send_version('1.31'):
-            raise NotImplemented(_('Incompatible conductor version - '
-                                 'please upgrade ironic-conductor first'))
+            raise NotImplementedError(_('Incompatible conductor version - '
+                                        'please upgrade ironic-conductor '
+                                        'first'))
         cctxt = self.client.prepare(topic=self.topic, version='1.31')
         return cctxt.call(context, 'object_class_action_versions',
                           objname=objname, objmethod=objmethod,
@@ -630,13 +685,15 @@ class ConductorAPI(object):
         :param objmethod: The name of the action method to call
         :param args: The positional arguments to the action method
         :param kwargs: The keyword arguments to the action method
-        :raises: NotImplemented when an operator makes an error during upgrade
+        :raises: NotImplementedError when an operator makes an error during
+            upgrade
         :returns: A tuple with the updates made to the object and
             the result of the action method
         """
         if not self.client.can_send_version('1.31'):
-            raise NotImplemented(_('Incompatible conductor version - '
-                                 'please upgrade ironic-conductor first'))
+            raise NotImplementedError(_('Incompatible conductor version - '
+                                        'please upgrade ironic-conductor '
+                                        'first'))
         cctxt = self.client.prepare(topic=self.topic, version='1.31')
         return cctxt.call(context, 'object_action', objinst=objinst,
                           objmethod=objmethod, args=args, kwargs=kwargs)
@@ -654,12 +711,14 @@ class ConductorAPI(object):
         :param context: The context within which to perform the backport
         :param objinst: An instance of a VersionedObject to be backported
         :param object_versions: A dict of {objname: version} mappings
-        :raises: NotImplemented when an operator makes an error during upgrade
+        :raises: NotImplementedError when an operator makes an error during
+            upgrade
         :returns: The downgraded instance of objinst
         """
         if not self.client.can_send_version('1.31'):
-            raise NotImplemented(_('Incompatible conductor version - '
-                                 'please upgrade ironic-conductor first'))
+            raise NotImplementedError(_('Incompatible conductor version - '
+                                        'please upgrade ironic-conductor '
+                                        'first'))
         cctxt = self.client.prepare(topic=self.topic, version='1.31')
         return cctxt.call(context, 'object_backport_versions', objinst=objinst,
                           object_versions=object_versions)
