@@ -117,6 +117,40 @@ def add_port_filter_by_node(query, value):
         return query.filter(models.Node.uuid == value)
 
 
+def add_portgroup_filter(query, value):
+    """Adds a portgroup-specific filter to a query.
+
+    Filters results by address, if supplied value is a valid MAC
+    address. Otherwise attempts to filter results by identity.
+
+    :param query: Initial query to add filter to.
+    :param value: Value for filtering results by.
+    :return: Modified query.
+    """
+    if utils.is_valid_mac(value):
+        return query.filter_by(address=value)
+    else:
+        return add_identity_filter(query, value)
+
+
+def add_portgroup_filter_by_node(query, value):
+    if strutils.is_int_like(value):
+        return query.filter_by(node_id=value)
+    else:
+        query = query.join(models.Node,
+                           models.Portgroup.node_id == models.Node.id)
+        return query.filter(models.Node.uuid == value)
+
+
+def add_port_filter_by_portgroup(query, value):
+    if strutils.is_int_like(value):
+        return query.filter_by(portgroup_id=value)
+    else:
+        query = query.join(models.Portgroup,
+                           models.Port.portgroup_id == models.Portgroup.id)
+        return query.filter(models.Portgroup.uuid == value)
+
+
 def add_node_filter_by_chassis(query, value):
     if strutils.is_int_like(value):
         return query.filter_by(chassis_id=value)
@@ -222,7 +256,7 @@ class Connection(api.Connection):
                 if count != 1:
                     # Nothing updated and node exists. Must already be
                     # locked.
-                    raise exception.NodeLocked(node=node_id,
+                    raise exception.NodeLocked(node=node.uuid,
                                                host=node['reservation'])
                 return node
             except NoResultFound:
@@ -239,9 +273,9 @@ class Connection(api.Connection):
                 if count != 1:
                     node = query.one()
                     if node['reservation'] is None:
-                        raise exception.NodeNotLocked(node=node_id)
+                        raise exception.NodeNotLocked(node=node.uuid)
                     else:
-                        raise exception.NodeLocked(node=node_id,
+                        raise exception.NodeLocked(node=node.uuid,
                                                    host=node['reservation'])
             except NoResultFound:
                 raise exception.NodeNotFound(node_id)
@@ -255,6 +289,14 @@ class Connection(api.Connection):
         if 'provision_state' not in values:
             values['provision_state'] = states.ENROLL
 
+        # TODO(zhenguo): Support creating node with tags
+        if 'tags' in values:
+            LOG.warning(
+                _LW('Ignore the specified tags %(tags)s when creating node: '
+                    '%(node)s.'), {'tags': values['tags'],
+                                   'node': values['uuid']})
+            del values['tags']
+
         node = models.Node()
         node.update(values)
         with _session_for_write() as session:
@@ -325,6 +367,15 @@ class Connection(api.Connection):
             port_query = add_port_filter_by_node(port_query, node_id)
             port_query.delete()
 
+            portgroup_query = model_query(models.Portgroup)
+            portgroup_query = add_portgroup_filter_by_node(portgroup_query,
+                                                           node_id)
+            portgroup_query.delete()
+
+            # Delete all tags attached to the node
+            tag_query = model_query(models.NodeTag).filter_by(node_id=node_id)
+            tag_query.delete()
+
             query.delete()
 
     def update_node(self, node_id, values):
@@ -359,7 +410,7 @@ class Connection(api.Connection):
             # Prevent instance_uuid overwriting
             if values.get("instance_uuid") and ref.instance_uuid:
                 raise exception.NodeAssociated(
-                    node=node_id, instance=ref.instance_uuid)
+                    node=ref.uuid, instance=ref.instance_uuid)
 
             if 'provision_state' in values:
                 values['provision_updated_at'] = timeutils.utcnow()
@@ -410,6 +461,13 @@ class Connection(api.Connection):
         return _paginate_query(models.Port, limit, marker,
                                sort_key, sort_dir, query)
 
+    def get_ports_by_portgroup_id(self, portgroup_id, limit=None, marker=None,
+                                  sort_key=None, sort_dir=None):
+        query = model_query(models.Port)
+        query = query.filter_by(portgroup_id=portgroup_id)
+        return _paginate_query(models.Port, limit, marker,
+                               sort_key, sort_dir, query)
+
     def create_port(self, values):
         if not values.get('uuid'):
             values['uuid'] = uuidutils.generate_uuid()
@@ -453,6 +511,109 @@ class Connection(api.Connection):
             if count == 0:
                 raise exception.PortNotFound(port=port_id)
 
+    def get_portgroup_by_id(self, portgroup_id):
+        query = model_query(models.Portgroup).filter_by(id=portgroup_id)
+        try:
+            return query.one()
+        except NoResultFound:
+            raise exception.PortgroupNotFound(portgroup=portgroup_id)
+
+    def get_portgroup_by_uuid(self, portgroup_uuid):
+        query = model_query(models.Portgroup).filter_by(uuid=portgroup_uuid)
+        try:
+            return query.one()
+        except NoResultFound:
+            raise exception.PortgroupNotFound(portgroup=portgroup_uuid)
+
+    def get_portgroup_by_address(self, address):
+        query = model_query(models.Portgroup).filter_by(address=address)
+        try:
+            return query.one()
+        except NoResultFound:
+            raise exception.PortgroupNotFound(portgroup=address)
+
+    def get_portgroup_by_name(self, name):
+        query = model_query(models.Portgroup).filter_by(name=name)
+        try:
+            return query.one()
+        except NoResultFound:
+            raise exception.PortgroupNotFound(portgroup=name)
+
+    def get_portgroup_list(self, limit=None, marker=None,
+                           sort_key=None, sort_dir=None):
+        return _paginate_query(models.Portgroup, limit, marker,
+                               sort_key, sort_dir)
+
+    def get_portgroups_by_node_id(self, node_id, limit=None, marker=None,
+                                  sort_key=None, sort_dir=None):
+        query = model_query(models.Portgroup)
+        query = query.filter_by(node_id=node_id)
+        return _paginate_query(models.Portgroup, limit, marker,
+                               sort_key, sort_dir, query)
+
+    def create_portgroup(self, values):
+        if not values.get('uuid'):
+            values['uuid'] = uuidutils.generate_uuid()
+
+        portgroup = models.Portgroup()
+        portgroup.update(values)
+        with _session_for_write() as session:
+            try:
+                session.add(portgroup)
+                session.flush()
+            except db_exc.DBDuplicateEntry as exc:
+                if 'name' in exc.columns:
+                    raise exception.PortgroupDuplicateName(name=values['name'])
+                elif 'address' in exc.columns:
+                    raise exception.PortgroupMACAlreadyExists(
+                        mac=values['address'])
+                raise exception.PortgroupAlreadyExists(uuid=values['uuid'])
+            return portgroup
+
+    def update_portgroup(self, portgroup_id, values):
+        if 'uuid' in values:
+            msg = _("Cannot overwrite UUID for an existing portgroup.")
+            raise exception.InvalidParameterValue(err=msg)
+
+        with _session_for_write() as session:
+            try:
+                query = model_query(models.Portgroup)
+                query = add_portgroup_filter(query, portgroup_id)
+                ref = query.one()
+                ref.update(values)
+                session.flush()
+            except NoResultFound:
+                raise exception.PortgroupNotFound(portgroup=portgroup_id)
+            except db_exc.DBDuplicateEntry as exc:
+                if 'name' in exc.columns:
+                    raise exception.PortgroupDuplicateName(name=values['name'])
+                elif 'address' in exc.columns:
+                    raise exception.PortgroupMACAlreadyExists(
+                        mac=values['address'])
+                else:
+                    raise exc
+            return ref
+
+    def destroy_portgroup(self, portgroup_id):
+        def portgroup_not_empty(session):
+            """Checks whether the portgroup does not have ports."""
+
+            query = model_query(models.Port)
+            query = add_port_filter_by_portgroup(query, portgroup_id)
+
+            return query.count() != 0
+
+        with _session_for_write() as session:
+            if portgroup_not_empty(session):
+                raise exception.PortgroupNotEmpty(portgroup=portgroup_id)
+
+            query = model_query(models.Portgroup, session=session)
+            query = add_identity_filter(query, portgroup_id)
+
+            count = query.delete()
+            if count == 0:
+                raise exception.PortgroupNotFound(portgroup=portgroup_id)
+
     def get_chassis_by_id(self, chassis_id):
         query = model_query(models.Chassis).filter_by(id=chassis_id)
         try:
@@ -614,3 +775,59 @@ class Connection(api.Connection):
             count = query.update({'provision_updated_at': timeutils.utcnow()})
             if count == 0:
                 raise exception.NodeNotFound(node_id)
+
+    def _check_node_exists(self, node_id):
+        if not model_query(models.Node).filter_by(id=node_id).scalar():
+            raise exception.NodeNotFound(node=node_id)
+
+    def set_node_tags(self, node_id, tags):
+        # remove duplicate tags
+        tags = set(tags)
+        with _session_for_write() as session:
+            self.unset_node_tags(node_id)
+            node_tags = []
+            for tag in tags:
+                node_tag = models.NodeTag(tag=tag, node_id=node_id)
+                session.add(node_tag)
+                node_tags.append(node_tag)
+
+        return node_tags
+
+    def unset_node_tags(self, node_id):
+        self._check_node_exists(node_id)
+        with _session_for_write():
+            model_query(models.NodeTag).filter_by(node_id=node_id).delete()
+
+    def get_node_tags_by_node_id(self, node_id):
+        self._check_node_exists(node_id)
+        result = (model_query(models.NodeTag)
+                  .filter_by(node_id=node_id)
+                  .all())
+        return result
+
+    def add_node_tag(self, node_id, tag):
+        node_tag = models.NodeTag(tag=tag, node_id=node_id)
+
+        self._check_node_exists(node_id)
+        try:
+            with _session_for_write() as session:
+                session.add(node_tag)
+                session.flush()
+        except db_exc.DBDuplicateEntry:
+            # NOTE(zhenguo): ignore tags duplicates
+            pass
+
+        return node_tag
+
+    def delete_node_tag(self, node_id, tag):
+        self._check_node_exists(node_id)
+        with _session_for_write():
+            result = model_query(models.NodeTag).filter_by(
+                node_id=node_id, tag=tag).delete()
+
+            if not result:
+                raise exception.NodeTagNotFound(node_id=node_id, tag=tag)
+
+    def node_tag_exists(self, node_id, tag):
+        q = model_query(models.NodeTag).filter_by(node_id=node_id, tag=tag)
+        return model_query(q.exists()).scalar()
