@@ -26,6 +26,7 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
+from oslo_utils import strutils
 import six
 from six.moves.urllib import parse
 
@@ -96,10 +97,12 @@ SUPPORTED_CAPABILITIES = {
     'disk_label': ('msdos', 'gpt'),
 }
 
+DISK_LAYOUT_PARAMS = ('root_gb', 'swap_mb', 'ephemeral_gb')
 
 # All functions are called from deploy() directly or indirectly.
 # They are split for stub-out.
 
+
 def discovery(portal_address, portal_port):
     """Do iSCSI discovery on portal."""
     utils.execute('iscsiadm',
@@ -1084,3 +1087,111 @@ def get_image_instance_info(node):
     check_for_missing_params(info, error_msg)
 
     return info
+
+
+def parse_instance_info(node):
+    """Gets the instance specific Node deployment info.
+
+    This method validates whether the 'instance_info' property of the
+    supplied node contains the required information for this driver to
+    deploy images to the node.
+
+    :param node: a single Node.
+    :returns: A dict with the instance_info values.
+    :raises: MissingParameterValue, if any of the required parameters are
+        missing.
+    :raises: InvalidParameterValue, if any of the parameters have invalid
+        value.
+    """
+
+    info = node.instance_info
+    i_info = {}
+    i_info['image_source'] = info.get('image_source')
+    iwdi = node.driver_internal_info.get('is_whole_disk_image')
+    if not iwdi:
+        if (i_info['image_source'] and
+                not service_utils.is_glance_image(
+                    i_info['image_source'])):
+            i_info['kernel'] = info.get('kernel')
+            i_info['ramdisk'] = info.get('ramdisk')
+    i_info['root_gb'] = info.get('root_gb')
+
+    error_msg = _("Cannot validate driver deploy. Some parameters were missing"
+                  " in node's instance_info")
+    check_for_missing_params(i_info, error_msg)
+
+    # Internal use only
+    i_info['deploy_key'] = info.get('deploy_key')
+    i_info['swap_mb'] = int(info.get('swap_mb', 0))
+    i_info['ephemeral_gb'] = info.get('ephemeral_gb', 0)
+    err_msg_invalid = _("Cannot validate parameter for driver deploy. "
+                        "Invalid parameter %(param)s. Reason: %(reason)s")
+    for param in DISK_LAYOUT_PARAMS:
+        try:
+            int(i_info[param])
+        except ValueError:
+            reason = _("%s is not an integer value.") % i_info[param]
+            raise exception.InvalidParameterValue(err_msg_invalid %
+                                                  {'param': param,
+                                                   'reason': reason})
+
+    i_info['root_mb'] = 1024 * int(info.get('root_gb'))
+
+    if iwdi:
+        if int(i_info['swap_mb']) > 0 or int(i_info['ephemeral_gb']) > 0:
+            err_msg_invalid = _("Cannot deploy whole disk image with "
+                                "swap or ephemeral size set")
+            raise exception.InvalidParameterValue(err_msg_invalid)
+    i_info['ephemeral_format'] = info.get('ephemeral_format')
+    i_info['configdrive'] = info.get('configdrive')
+
+    if i_info['ephemeral_gb'] and not i_info['ephemeral_format']:
+        i_info['ephemeral_format'] = CONF.pxe.default_ephemeral_format
+
+    preserve_ephemeral = info.get('preserve_ephemeral', False)
+    try:
+        i_info['preserve_ephemeral'] = (
+            strutils.bool_from_string(preserve_ephemeral, strict=True))
+    except ValueError as e:
+        raise exception.InvalidParameterValue(
+            err_msg_invalid % {'param': 'preserve_ephemeral', 'reason': e})
+
+    # NOTE(Zhenguo): If rebuilding with preserve_ephemeral option, check
+    # that the disk layout is unchanged.
+    if i_info['preserve_ephemeral']:
+        _check_disk_layout_unchanged(node, i_info)
+
+    return i_info
+
+
+def _check_disk_layout_unchanged(node, i_info):
+    """Check whether disk layout is unchanged.
+
+    If the node has already been deployed to, this checks whether the disk
+    layout for the node is the same as when it had been deployed to.
+
+    :param node: the node of interest
+    :param i_info: instance information (a dictionary) for the node, containing
+                   disk layout information
+    :raises: InvalidParameterValue if the disk layout changed
+    """
+    # If a node has been deployed to, this is the instance information
+    # used for that deployment.
+    driver_internal_info = node.driver_internal_info
+    if 'instance' not in driver_internal_info:
+        return
+
+    error_msg = ''
+    for param in DISK_LAYOUT_PARAMS:
+        param_value = int(driver_internal_info['instance'][param])
+        if param_value != int(i_info[param]):
+            error_msg += (_(' Deployed value of %(param)s was %(param_value)s '
+                            'but requested value is %(request_value)s.') %
+                          {'param': param, 'param_value': param_value,
+                           'request_value': i_info[param]})
+
+    if error_msg:
+        err_msg_invalid = _("The following parameters have different values "
+                            "from previous deployment:%(error_msg)s")
+        raise exception.InvalidParameterValue(err_msg_invalid %
+                                              {'error_msg': error_msg})
