@@ -21,6 +21,7 @@ Ironic Native IPMI power manager.
 
 import os
 
+from ironic_lib import utils as ironic_utils
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
@@ -605,24 +606,19 @@ class NativeIPMIShellinaboxConsole(base.ConsoleInterface):
                                                     console_cmd)
         except exception.ConsoleError:
             with excutils.save_and_reraise_exception():
-                utils.unlink_without_raise(path)
+                ironic_utils.unlink_without_raise(path)
 
     def stop_console(self, task):
         """Stop the remote console session for the node.
 
         :param task: a TaskManager instance containing the node to act on.
-        :raises: MissingParameterValue when required IPMI credentials or
-            the IPMI terminal port are missing
-        :raises: InvalidParameterValue when the IPMI terminal port is not
-                an integer.
         :raises: ConsoleError if unable to stop the console process.
         """
-        driver_info = _parse_driver_info(task.node)
         try:
-            console_utils.stop_shellinabox_console(driver_info['uuid'])
+            console_utils.stop_shellinabox_console(task.node.uuid)
         finally:
-            password_file = _console_pwfile_path(driver_info['uuid'])
-            utils.unlink_without_raise(password_file)
+            password_file = _console_pwfile_path(task.node.uuid)
+            ironic_utils.unlink_without_raise(password_file)
 
     def get_console(self, task):
         """Get the type and connection information about the console.
