@@ -24,6 +24,10 @@ from ironic.objects import fields as object_fields
 
 @base.IronicObjectRegistry.register
 class Conductor(base.IronicObject, object_base.VersionedObjectDictCompat):
+    # Version 1.0: Initial version
+    # Version 1.1: Add register() and unregister(), make the context parameter
+    #              to touch() optional.
+    VERSION = '1.1'
 
     dbapi = db_api.get_instance()
 
@@ -79,6 +83,37 @@ class Conductor(base.IronicObject, object_base.VersionedObjectDictCompat):
     # methods can be used in the future to replace current explicit RPC calls.
     # Implications of calling new remote procedures should be thought through.
     # @object_base.remotable
-    def touch(self, context):
+    def touch(self, context=None):
         """Touch this conductor's DB record, marking it as up-to-date."""
         self.dbapi.touch_conductor(self.hostname)
+
+    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
+    # methods can be used in the future to replace current explicit RPC calls.
+    # Implications of calling new remote procedures should be thought through.
+    # @object_base.remotable
+    @classmethod
+    def register(cls, context, hostname, drivers, update_existing=False):
+        """Register an active conductor with the cluster.
+
+        :param hostname: the hostname on which the conductor will run
+        :param drivers: the list of drivers enabled in the conductor
+        :param update_existing: When false, registration will raise an
+                                exception when a conflicting online record
+                                is found. When true, will overwrite the
+                                existing record. Default: False.
+        :raises: ConductorAlreadyRegistered
+        :returns: a :class:`Conductor` object.
+
+        """
+        db_cond = cls.dbapi.register_conductor({'hostname': hostname,
+                                                'drivers': drivers},
+                                               update_existing=update_existing)
+        return Conductor._from_db_object(cls(context), db_cond)
+
+    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
+    # methods can be used in the future to replace current explicit RPC calls.
+    # Implications of calling new remote procedures should be thought through.
+    # @object_base.remotable
+    def unregister(self, context=None):
+        """Remove this conductor from the service registry."""
+        self.dbapi.unregister_conductor(self.hostname)
