@@ -22,7 +22,7 @@ from ironic_tempest_plugin.services.baremetal.v1.json.baremetal_client import \
 
 CONF = config.CONF
 
-ADMIN_CREDS = common_creds.get_configured_credentials('identity_admin')
+ADMIN_CREDS = common_creds.get_configured_admin_credentials()
 
 
 class Manager(clients.Manager):
